==> fwbuilder_3.0.2.orig.tar.gz: fwbuilder-3.0.2/src/ipt/combinedAddress.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2002 NetCitadel, LLC

  Author:  Vadim Kurland <vadim@vk.crocodile.org>

  $Id: combinedAddress.h 312 2008-07-05 17:40:12Z vadim $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef __COMB_ADDRESS_HH_FLAG__
#define __COMB_ADDRESS_HH_FLAG__

#include <fwbuilder/FWObject.h>
#include <fwbuilder/IPv4.h>
#include <fwbuilder/physAddress.h>

namespace libfwbuilder
{

class combinedAddress : public IPv4
{
    private:

    std::string physAddress;

    public:

    DECLARE_FWOBJECT_SUBTYPE(combinedAddress);

    combinedAddress() {}
    combinedAddress(const FWObject *root,bool prepopulate);
    virtual ~combinedAddress();

    virtual FWObject& shallowDuplicate(const FWObject *obj,
                                       bool preserve_id = true)
        throw(FWException);
    
    std::string getPhysAddress() const;
    void setPhysAddress(const std::string &s);

    bool isAny() const;
};

}


#endif

==> fwbuilder_3.0.7.orig.tar.gz: fwbuilder-3.0.7/src/ipt/combinedAddress.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2002 NetCitadel, LLC

  Author:  Vadim Kurland <vadim@vk.crocodile.org>

  $Id: combinedAddress.h 709 2008-12-25 20:38:53Z vadim $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef __COMB_ADDRESS_HH_FLAG__
#define __COMB_ADDRESS_HH_FLAG__

#include <fwbuilder/FWObject.h>
#include <fwbuilder/IPv4.h>
#include <fwbuilder/physAddress.h>

namespace libfwbuilder
{

class combinedAddress : public IPv4
{
    private:

    std::string physAddress;

    public:

    DECLARE_FWOBJECT_SUBTYPE(combinedAddress);

    combinedAddress() {}
    combinedAddress(const FWObjectDatabase *root,bool prepopulate);
    virtual ~combinedAddress();

    virtual FWObject& shallowDuplicate(const FWObject *obj,
                                       bool preserve_id = true)
        throw(FWException);
    
    std::string getPhysAddress() const;
    void setPhysAddress(const std::string &s);

    bool isAny() const;
};

}


#endif
